=== modified file 'tags.py'
--- tags.py	2007-04-08 21:08:06 +0000
+++ tags.py	2007-04-09 22:03:11 +0000
@@ -47,7 +47,12 @@
         self._vpaned = gtk.VPaned()
         
         # Set callbacks
+        self._button_add.connect('clicked', self._on_add_clicked)
         self._button_close.connect('clicked', self._on_close_clicked)
+        self._button_remove.connect('clicked', self._on_remove_clicked)
+        self._treeview_tags.connect('cursor-changed', self._on_treeview_changed)
+        if parent is None:
+            self.connect('delete-event', gtk.main_quit)
         
         # Set properties
         self.set_title(_("Tags - Olive"))
@@ -70,11 +75,70 @@
         
         self.add(self._hbox)
         
+        # Load the tags
+        self._load_tags()
+        
         # Display everything
         self._hbox.show_all()
     
+    def _load_tags(self):
+        """ Load the tags into the TreeView. """
+        self._treeview_tags.append_column(gtk.TreeViewColumn(_("Tag Name"),
+                                                             gtk.CellRendererText(),
+                                                             text=0))
+        self._treeview_tags.append_column(gtk.TreeViewColumn(_("Revision ID"),
+                                                             gtk.CellRendererText(),
+                                                             text=1))
+        
+        self._refresh_tags()
+    
+    def _refresh_tags(self):
+        """ Refresh the list of tags. """
+        self._model.clear()
+        if self.branch.supports_tags():
+            tags = self.branch.tags.get_tag_dict()
+            if len(tags) > 0:
+                for name, target in tags.items():
+                    self._model.append([name, target])
+            else:
+                self._no_tags()
+        else:
+            self._tags_not_supported()
+        
+        self._treeview_tags.set_model(self._model)
+    
+    def _tags_not_supported(self):
+        """ Tags are not supported. """
+        self._model.append([_("Tags are not supported by this branch format. Please upgrade."), ""])
+        self._button_add.set_sensitive(False)
+        self._button_remove.set_sensitive(False)
+    
+    def _no_tags(self):
+        """ No tags in the branch. """
+        self._model.append([_("No tagged revisions in the branch."), ""])
+        self._button_remove.set_sensitive(False)
+    
+    def _on_add_clicked(self, widget):
+        """ Add button event handler. """
+        return
+    
     def _on_close_clicked(self, widget):
         """ Close button event handler. """
         self.destroy()
         if self._parent is None:
             gtk.main_quit()
+    
+    def _on_remove_clicked(self, widget):
+        """ Remove button event handler. """
+        (path, col) = self._treeview_tags.get_cursor()
+        tag = self._model[path][0]
+        
+        self.branch.tags.delete_tag(tag)
+        self._refresh_tags()
+    
+    def _on_treeview_changed(self, *args):
+        """ When a user clicks on a tag. """
+        (path, col) = self._treeview_tags.get_cursor()
+        revision = self._model[path][1]
+        
+        self._logview.set_revision(self.branch.repository.get_revision(revision))

